#if !defined(LVSpeechPort_h)
#define LVSpeechPort_h

#include "LV_SRE.h"
#include <iostream>
//*********************************************************************

//note: this class has become a user-side lightweight wrapper around the "C" API,
//      you can bypass this class and call the "C" functions directly
class LVSpeechPort
{
public:

	LVSpeechPort();
	virtual ~LVSpeechPort();

	int AddEvent(const char* eventName);
	int AddEventEx(const char* eventName, const char* eventData);

	int AddFieldToRequest(const char* KeyName, const char* String);
	int ClearAllFieldsToRequest();

	int GetDecodeMS(int voicechannel);
	int GetTotalDecodeMS(int voicechannel);


	//Initialize new port, must be done before usable.
	// Vebosity level 
	//		0 will only return fatal errors
	//		1 non fatal error
	//		2-5 progressivly more detailed info
	
	int CreateClient(ExportLogMsg Log = NULL, void* p = NULL, int NewMsgVerbosity = 0);

	//Called to shut down speech rec port
	int DestroyClient();

	//Length is sound data length in bytes.
	int LoadVoiceChannel(int VoiceChannel, void* M,int Length,
                         SOUND_FORMAT Format = ULAW_8KHZ);//, 
                         //const char* SoundFileName = NULL);

                                              //LV_DECODE_BLOCK | LV_DECODE_USE_OOV
    int Decode(int VoiceChannel,int GrammarSet,unsigned int flags = 0);
    
	float MeasurePitch(int VoiceChannel);
	float MeasureEnergy(int VoiceChannel);

	int DTMFDecode(const char* dtmf_str, unsigned int flags);
    int InterpretText(const char* text, unsigned flags);


	int GetNumberOfNBestAlternatives(int VoiceChannel);
	int SwitchToNBestAlternative(int VoiceChannel, int index);


	//This will return a pointer to the VoiceChannels sound Data.
	//This is always in PCM 16,000 Khz, any sound data sent to channel 
	//is converted into this format before decoding.
	//Samples is filled with number of samples of sound data,
	//this is always 1/2 the number of bytes.
	int	GetVoiceChannelData(int VoiceChannel, short** PCM,  unsigned int* Samples);

	//If OOV is true decoder is better at scoring confidence values 
	//especially out-of-vocabulary words however
	//the engine but runs a little slower
	   

	//If OOV is false decoder is faster but confidence values 
	//are much lesss usefull

    //the following has been removed.
	//int ActivateGrammar(int GrammarSet, bool UseOOV = true);

	int WaitForEngineToIdle(int MillisecondsToWait,int VoiceChannel = -1);

	int WaitForDecode(int VoiceChannel = -1);
	
	//Returns a string explaining error code.
    static const char* ReturnErrorString(int ReturnCode);
	
	//Sets property values
    int SetPropertyEx(int property,int valuetype,void *pvalue,int target = PROP_EX_TARGET_PORT,int ndx = 0);
	static int SetClientPropertyEx(int property, int valuetype, void* pvalue);

	// Query properties
	int GetIntPropertyEx(int property, int target, int &pvalue);
	int GetFloatPropertyEx(int property, int target, float &pvalue);
	int GetStringPropertyEx(int property, int target, char *value_str, int value_len_bytes, int &actual_value_len);
	static int GetClientIntPropertyEx(int property, int &pvalue);
	static int GetClientFloatPropertyEx(int property, float &pvalue);
	static int GetClientStringPropertyEx(int property, char *value_str, int value_len_bytes, int &actual_value_len);

    //bool SetLanguage(const char *pszlangstr);//This is no longer supported

    static void RegisterAppLogMsg(ExportLogMsg Log,void* p = NULL,int NewMsgVerbosity = 0);
 
    static void Startup();//optional, currently not needed.
    static void Shutdown();//optional, allows backend sre threads to shutdown gracefully.


    HPORT GetHPort() const;
    void  SetHPort(HPORT port);

	//Version 4.0 additions
	int StreamStart();
	int StreamSendData(void* SoundData, int SoundDataLength);
	int StreamGetStatus();
	int StreamGetLength();
	int StreamSetStateChangeCallBack(LV_SRE_StreamStateChangeFn* fn, void* UserData);
	int StreamStop();
	int StreamCancel();
	int StreamSetParameter(int StreamParameter, unsigned int  StreamParameterValue);
	int StreamGetParameter(int StreamParameter, unsigned int* StreamParameterValue);
	int StreamSetParameterToDefault(int StreamParameter);

	//Version 4.1 adds support for LumenVox's implementation of SRGS-ABNF grammars

	//Load a grammar from a location.  The grammar can be named after the uri, or an index.
	int LoadGrammar(const char* label, const char* uri);
	int LoadGrammar(const char* label_is_uri);  //label and uri are the same

	//Load a grammar from a null terminated string.  The grammars name can be an alphanumeric string,
	//a uri string (not necessarily a location), or an index
	int LoadGrammarFromBuffer(const char* label, const char* buffer_string);

	int LoadGrammarFromObject(const char* label, LVGrammar& Grammar);

	//Use when LoadGrammar returns LV_GRAMMAR_SYNTAX_ERROR or LV_GRAMMAR_SYNTAX_WARNING to get debugging info
	const char* ReturnGrammarErrorString(const char* GrammarLabel);

	bool IsGrammarLoaded(const char* label);
	//Unload the grammar by its name.
	int UnloadGrammar(const char* label);

	//unload all grammars
	int UnloadGrammars();

	//Application-Level grammars, usable by all speechports.
	static int LoadGlobalGrammar(const char* label, const char* uri);
	static int LoadGlobalGrammar(const char* label_is_uri);
	static int LoadGlobalGrammarFromBuffer(const char* label, const char* buffer_string);
	static int LoadGlobalGrammarFromObject(const char* label, LVGrammar& Grammar);
	static int UnloadGlobalGrammar(const char* uri);

	//Get the vocabulary size for a loaded grammar
	int GetGrammarVocabSize(const char* name);
	//Activate a grammar for a decode.  Multiple grammars can be active at once.  They can come from the
	//speechports pool of grammars, or the global collection.
	int ActivateGrammar(const char* name);
	//only needed if there is a name conflict between your port grammars and the 
	//global grammars, and you wish to activate a global.  otherwise just use activate
	int ActivateGlobalGrammar(const char* name);

	//deactivate a grammar
	int DeactivateGrammar(const char* name);
	int DeactivateGrammar(int index);
	//deprecated.  Just use DeactivateGrammar
	//int DeactivateGlobalGrammar(const char* name);
    
	//Get return values from the decode
	int GetNumberOfParses(int voice_channel);
	int GetUtteranceScore(int voice_channel);


	const char* GetParseTreeString(int voice_channel, int index);
	LVParseTree GetParseTree(int voice_channel, int index);

	int GetNumberOfInterpretations(int voice_channel);
	LVInterpretation GetInterpretation(int voice_channel, int index);
	const char* GetInterpretationString(int voice_channel,int index);
	
	//Begin DEPRECATED: These function calls are deprecated in favor of using GetInterpretation
	LVSemanticData	GetInterpretationData(int voice_channel, int index);
	const char* GetInterpretationPhonemes(int voice_channel, int index);
	const char* GetInterpretationGrammarLabel(int voice_channel, int index);
	const char* GetInterpretationLanguage(int voice_channel, int index);
	const char* GetInterpretationMode(int voice_channel, int index);
	const char* GetInterpretationTopLevelRule(int voice_channel, int index);
	const char* GetInterpretationInputString(int voice_channel, int index);
	int GetInterpretationScore(int voice_channel, int index);
	//End DEPRECATED

 
   //helper class, instantiate at top of "main"
   class TInitializer
   {
    public:
      TInitializer() {Startup();}
      ~TInitializer() {Shutdown();}
   };

	int GetLastDecodeError(int voice_channel);

	int GetOpenPortStatus(){return OpenPortErrorCode;}

	int	DeactivateGrammars();

	static unsigned int GetAvailableLicensesCount(const char *license_type);

	static bool IsServerAvailable();

protected:
	int OpenPortErrorCode;	

	volatile HPORT HPort;


DEPRECATED_LVSPEECHPORT_METHODS
};


//*********************************************************************
//********************** inlines **************************************
//*********************************************************************
inline
LVSpeechPort::LVSpeechPort()
:HPort(NULL)
{
	OpenPortErrorCode = LV_OPEN_PORT_FAILED__OPEN_PORT_NOT_CALLED_YET;
}
//*********************************************************************
inline
//virtual 
LVSpeechPort::~LVSpeechPort()
{
  ClosePort();
}

//*********************************************************************
inline
int LVSpeechPort::AddEvent(const char* eventName)
{
	return AddEventEx(eventName, NULL);
}
inline
int LVSpeechPort::AddEventEx(const char* eventName, const char* eventData)
{
	return LV_SRE_AddEventEx(HPort, eventName, eventData);
}
//*********************************************************************
inline
int LVSpeechPort::CreateClient(ExportLogMsg Log, void* p, int NewMsgVerbosity)
{
  if (!HPort)
	{
	 HPort = LV_SRE_CreateClient(&OpenPortErrorCode, Log,p,NewMsgVerbosity);
	}
  else return LV_SYSTEM_ERROR;
  return HPort ? LV_SUCCESS : LV_FAILURE;
}
//*********************************************************************
inline
int LVSpeechPort::DestroyClient() 
{
	HPORT local_hport = HPort;
	HPort = NULL;	//moved this above the call to destroy the port so that other threads will not use it while being destroyed
	int rc = LV_SRE_DestroyClient(local_hport);
  return rc;
}
//*********************************************************************
inline
int LVSpeechPort::LoadVoiceChannel(int VoiceChannel, void* M,int Length,
                                   SOUND_FORMAT Format)//, const char* SoundFileName)
{
  return LV_SRE_LoadVoiceChannel(HPort,VoiceChannel,M,Length,Format);//,SoundFileName);
}
//*********************************************************************
inline 
int LVSpeechPort::Decode(int VoiceChannel,int GrammarSet,unsigned int flags)
{
  return LV_SRE_Decode(HPort,VoiceChannel,GrammarSet,flags);
}
//*********************************************************************
inline 
float LVSpeechPort::MeasurePitch(int VoiceChannel)
{
  return LV_SRE_DecodePitch(HPort,VoiceChannel);
}
//*********************************************************************
inline 
float LVSpeechPort::MeasureEnergy(int VoiceChannel)
{
  return LV_SRE_DecodeEnergy(HPort,VoiceChannel);
}
//*********************************************************************
inline
int LVSpeechPort::DTMFDecode(const char* dtmf_str, unsigned int flags)
{
	return LV_SRE_DTMFDecode(HPort, dtmf_str, flags);
}
//*********************************************************************
inline
int LVSpeechPort::InterpretText(const char* text, unsigned flags)
{
    return LV_SRE_InterpretText(HPort, text, flags);
}
//*********************************************************************
inline
int	LVSpeechPort::GetVoiceChannelData(int VoiceChannel, short** PCM,  unsigned int* Samples)
{
  return LV_SRE_GetVoiceChannelData(HPort,VoiceChannel,PCM,Samples);
}
//********************************************************************
inline
int LVSpeechPort::WaitForEngineToIdle(int MillisecondsToWait,int voicechannel)
{
   return LV_SRE_WaitForEngineToIdle(HPort,voicechannel, MillisecondsToWait);
}
//*********************************************************************
inline
int LVSpeechPort::WaitForDecode(int VoiceChannel)
{
	return LV_SRE_WaitForDecode(HPort, VoiceChannel);
}
//*********************************************************************
inline	
//static 
const char* LVSpeechPort::ReturnErrorString(int ReturnCode)
{
  return LV_SRE_ReturnErrorString(ReturnCode);
}
//*********************************************************************
inline
const char* LVSpeechPort::ReturnGrammarErrorString(const char* GrammarLabel)
{
	return LV_SRE_ReturnGrammarErrorString(HPort, GrammarLabel);
}
//*********************************************************************
inline
int LVSpeechPort::SetPropertyEx(int property,int valuetype,void *pvalue,int target,int ndx)
{
  return LV_SRE_SetPropertyEx(HPort,property,valuetype,pvalue,target,ndx);
}
inline
int LVSpeechPort::SetClientPropertyEx(int property,int valuetype,void* pvalue)
{
	return LV_SRE_SetPropertyEx(NULL,property,valuetype,pvalue,PROP_EX_TARGET_CLIENT,0);
}
//*********************************************************************
inline
int LVSpeechPort::GetIntPropertyEx(int property, int target, int &pvalue)
{
	return LV_SRE_GetIntPropertyEx(HPort, property, target, &pvalue);
}
inline
int LVSpeechPort::GetFloatPropertyEx(int property, int target, float &pvalue)
{
	return LV_SRE_GetFloatPropertyEx(HPort, property, target, &pvalue);
}
inline
int LVSpeechPort::GetStringPropertyEx(int property, int target, char *value_str, int value_len_bytes, int &actual_value_len)
{
	return LV_SRE_GetStringPropertyEx(HPort, property, target, value_str, value_len_bytes, &actual_value_len);
}
inline
// static
int LVSpeechPort::GetClientIntPropertyEx(int property, int &pvalue)
{
	return LV_SRE_GetIntPropertyEx(NULL, property, PROP_EX_TARGET_CLIENT, &pvalue);
}
inline
// static
int LVSpeechPort::GetClientFloatPropertyEx(int property, float &pvalue)
{
	return LV_SRE_GetFloatPropertyEx(NULL, property, PROP_EX_TARGET_CLIENT, &pvalue);
}
inline
// static
int LVSpeechPort::GetClientStringPropertyEx(int property, char *value_str, int value_len_bytes, int &actual_value_len)
{
	return LV_SRE_GetStringPropertyEx(NULL, property, PROP_EX_TARGET_CLIENT, value_str, value_len_bytes, &actual_value_len);
}
//*********************************************************************
inline
//static 
void LVSpeechPort::RegisterAppLogMsg(ExportLogMsg Log,void* p,int NewMsgVerbosity)
{
  LV_SRE_RegisterAppLogMsg(Log,p,NewMsgVerbosity);
}
//*********************************************************************
inline
//static
void LVSpeechPort::Startup()
{
  LV_SRE_Startup();
}
//*********************************************************************
inline
//static
void LVSpeechPort::Shutdown()
{
  LV_SRE_Shutdown();
}
//*********************************************************************
inline
HPORT LVSpeechPort::GetHPort() const 
{
  return HPort;
}
//*********************************************************************
inline
void LVSpeechPort::SetHPort(HPORT hport) 
{
  HPort = hport;
}
//*********************************************************************
// This is no longer supported
//inline
//bool LVSpeechPort::SetLanguage(const char *pszlangstr)
//{
//  return LV_SUCCESS == SetPropertyEx(PROP_EX_LANGUAGE,
//                                     PROP_EX_VALUE_TYPE_STRING,
//                                     (void *)pszlangstr,
//                                     PROP_EX_TARGET_PORT,
//                                     0);
//}

//*********************************************************************
inline
int LVSpeechPort::AddFieldToRequest(const char* KeyName, const char* String)
{
	return LV_SRE_AddFieldToRequest(GetHPort(), KeyName, String);
}
//*********************************************************************
inline
int LVSpeechPort::ClearAllFieldsToRequest()
{
	return  LV_SRE_ClearAllFieldsToRequest(GetHPort());
}

//*********************************************************************
inline
int LVSpeechPort::GetDecodeMS(int voicechannel)
{
	return LV_SRE_GetDecodeMS(GetHPort(), voicechannel);
}

//*********************************************************************
inline
int LVSpeechPort::GetTotalDecodeMS(int voicechannel)
{
	return LV_SRE_GetTotalDecodeMS(GetHPort(), voicechannel);
}

//*********************************************************************
inline
int LVSpeechPort::StreamStart()
	{return LV_SRE_StreamStart(GetHPort());} 
//*********************************************************************
inline
int LVSpeechPort::StreamSendData(void* SoundData, int SoundDataLength)
	{return LV_SRE_StreamSendData(GetHPort(), SoundData, SoundDataLength);}

//*********************************************************************
inline
int LVSpeechPort::StreamGetStatus()
	{return LV_SRE_StreamGetStatus(GetHPort());}

//*********************************************************************
inline
int LVSpeechPort::StreamGetLength()
	{return LV_SRE_StreamGetLength(GetHPort());}
//*********************************************************************
inline
int LVSpeechPort::StreamSetStateChangeCallBack(LV_SRE_StreamStateChangeFn* fn, void* UserData)
	{return LV_SRE_StreamSetStateChangeCallBack(GetHPort(), fn, UserData);} 
//*********************************************************************
inline
int LVSpeechPort::StreamStop()
	{return LV_SRE_StreamStop(GetHPort());}  
//*********************************************************************
inline
int LVSpeechPort::StreamCancel()
	{return LV_SRE_StreamCancel(GetHPort());}  
//*********************************************************************
inline
int LVSpeechPort::StreamSetParameter(int StreamParameter, unsigned int  StreamParameterValue)
	{return LV_SRE_StreamSetParameter(GetHPort(), StreamParameter, StreamParameterValue);} 
//*********************************************************************
inline
int LVSpeechPort::StreamGetParameter(int StreamParameter, unsigned int* StreamParameterValue)
	{return LV_SRE_StreamGetParameter(GetHPort(), StreamParameter, StreamParameterValue);}
//*********************************************************************
inline
int LVSpeechPort::StreamSetParameterToDefault(int StreamParameter)
	{return LV_SRE_StreamSetParameterToDefault(GetHPort(), StreamParameter);}
//*********************************************************************
inline
int LVSpeechPort::LoadGrammar(const char* label, const char* uri)
{return LV_SRE_LoadGrammar(GetHPort(), label, uri);}
//*********************************************************************
inline
int LVSpeechPort::LoadGrammar(const char* label_is_uri)
{return LV_SRE_LoadGrammar(GetHPort(), label_is_uri, label_is_uri);}
//*********************************************************************
inline
int LVSpeechPort::LoadGrammarFromBuffer(const char* label, const char* buffer_string)
{return LV_SRE_LoadGrammarFromBuffer(GetHPort(),label,buffer_string);}
//*********************************************************************
inline
int LVSpeechPort::LoadGrammarFromObject(const char* label, LVGrammar& Grammar)
{return LV_SRE_LoadGrammarFromObject(GetHPort(),label,Grammar.GetHGrammar());}
//*********************************************************************
inline
bool LVSpeechPort::IsGrammarLoaded(const char* label)
{return LV_SRE_IsGrammarLoaded(GetHPort(),label) == 1;}
//*********************************************************************
inline
int LVSpeechPort::UnloadGrammar(const char* label)
{return LV_SRE_UnloadGrammar(GetHPort(),label);}

//*********************************************************************
inline
int LVSpeechPort::UnloadGrammars()
{
	return LV_SRE_UnloadGrammars(GetHPort());
}

//*********************************************************************
//static
inline
int LVSpeechPort::LoadGlobalGrammar(const char* label, const char* uri)
{return LV_SRE_LoadGlobalGrammar(label,uri);}
//*********************************************************************
//static
inline
int LVSpeechPort::LoadGlobalGrammar(const char* label_is_uri)
{return LV_SRE_LoadGlobalGrammar(label_is_uri,label_is_uri);}
//*********************************************************************
//static
inline
int LVSpeechPort::LoadGlobalGrammarFromBuffer(const char* label, const char* buffer_string)
{return LV_SRE_LoadGlobalGrammarFromBuffer(label,buffer_string);}
//*********************************************************************
//static
inline
int LVSpeechPort::LoadGlobalGrammarFromObject(const char* label, LVGrammar& Grammar)
{return LV_SRE_LoadGlobalGrammarFromObject(label,Grammar.GetHGrammar());}
//*********************************************************************
//static
inline
int LVSpeechPort::UnloadGlobalGrammar(const char* name)
{
	//std::cerr << "LVSpeechPort::UnloadGlobalGrammars - This functionality has been removed." << std::endl;
	return LV_SRE_UnloadGlobalGrammar(name);
}
//*********************************************************************
inline
int LVSpeechPort::GetGrammarVocabSize(const char* name)
{return LV_SRE_ReturnGrammarVocabSize(GetHPort(),name);}
//*********************************************************************
inline
int LVSpeechPort::ActivateGrammar(const char* name)
{return LV_SRE_ActivateGrammar(GetHPort(),name);}
//*********************************************************************
inline
int	LVSpeechPort::ActivateGlobalGrammar(const char* name)
{return LV_SRE_ActivateGlobalGrammar(GetHPort(),name);}
//*********************************************************************
inline
int	LVSpeechPort::DeactivateGrammar(const char* name)
{return LV_SRE_DeactivateGrammar(GetHPort(),name);}
//*********************************************************************
inline
int LVSpeechPort::GetNumberOfParses(int voice_channel)
{return LV_SRE_GetNumberOfParses(GetHPort(),voice_channel);}
//*********************************************************************
inline
const char* LVSpeechPort::GetParseTreeString(int voice_channel, int index)
{return LV_SRE_GetParseTreeString(GetHPort(),voice_channel, index);}
//*********************************************************************
inline 
LVParseTree LVSpeechPort::GetParseTree(int voice_channel, int index)
{return LVParseTree(LV_SRE_CreateParseTree(GetHPort(),voice_channel, index));}
//*********************************************************************
inline
int LVSpeechPort::GetNumberOfInterpretations(int voice_channel)
{return LV_SRE_GetNumberOfInterpretations(GetHPort(), voice_channel);}
//*********************************************************************
inline
const char* LVSpeechPort::GetInterpretationString(int voice_channel,int index)
{return LV_SRE_GetInterpretationString(GetHPort(),voice_channel, index);}
//*********************************************************************
inline
LVInterpretation LVSpeechPort::GetInterpretation(int voice_channel, int index)
{return LVInterpretation(LV_SRE_CreateInterpretation(GetHPort(), voice_channel,index));}
//*********************************************************************
inline
LVSemanticData LVSpeechPort::GetInterpretationData(int voice_channel, int index)
{
	LVSemanticData L;
	L.data = LV_SRE_GetInterpretationData(GetHPort(), voice_channel, index);
	return L;
}
//*********************************************************************
inline
const char* LVSpeechPort::GetInterpretationPhonemes(int voice_channel, int index)
{return LV_SRE_GetInterpretationPhonemes(GetHPort(), voice_channel, index);}

//*********************************************************************
inline
const char* LVSpeechPort::GetInterpretationGrammarLabel(int voice_channel, int index)
{return LV_SRE_GetInterpretationGrammarLabel(GetHPort(), voice_channel, index);}
//*********************************************************************
inline
const char* LVSpeechPort::GetInterpretationLanguage(int voice_channel, int index)
{return LV_SRE_GetInterpretationLanguage(GetHPort(), voice_channel, index);}
//*********************************************************************
inline
const char* LVSpeechPort::GetInterpretationMode(int voice_channel, int index)
{return LV_SRE_GetInterpretationMode(GetHPort(), voice_channel, index);}
//*********************************************************************
inline
const char* LVSpeechPort::GetInterpretationTopLevelRule(int voice_channel, int index)
{return LV_SRE_GetInterpretationTopLevelRule(GetHPort(), voice_channel, index);}

//*********************************************************************
inline
const char* LVSpeechPort::GetInterpretationInputString(int voice_channel, int index)
{return LV_SRE_GetInterpretationInputString(GetHPort(), voice_channel, index);}

//*********************************************************************
inline
int LVSpeechPort::GetInterpretationScore(int voice_channel, int index)
{return LV_SRE_GetInterpretationScore(GetHPort(), voice_channel, index);}

//*********************************************************************
inline
int LVSpeechPort::GetNumberOfNBestAlternatives(int voice_channel)
{return LV_SRE_GetNumberOfNBestAlternatives(GetHPort(), voice_channel);}

//*********************************************************************
inline
int LVSpeechPort::SwitchToNBestAlternative(int voice_channel, int index)
{return LV_SRE_SwitchToNBestAlternative(GetHPort(),voice_channel,index);}

//*********************************************************************
inline
int LVSpeechPort::GetLastDecodeError(int voice_channel)
{return LV_SRE_GetLastDecodeError(GetHPort(),voice_channel);}

//*********************************************************************
inline
int	LVSpeechPort::DeactivateGrammars()
{return LV_SRE_DeactivateGrammars(GetHPort());}

//*********************************************************************
inline
//static
unsigned int LVSpeechPort::GetAvailableLicensesCount(const char *license_type)
{
	return LV_SRE_GetAvailableLicensesCount(license_type);
}
//*********************************************************************
inline
//static
bool LVSpeechPort::IsServerAvailable()
{
	return LV_SRE_IsServerAvailable() ? true : false;
}

#ifndef IGNORE_LV_DEPRECATED
//*********************************************************************
inline
int LVSpeechPort::OpenPort(ExportLogMsg Log, void* p, int NewMsgVerbosity)
{
  return CreateClient(Log, p, NewMsgVerbosity);
}
//*********************************************************************
inline
int LVSpeechPort::ClosePort() 
{
	return DestroyClient();
}
#endif	// #ifndef IGNORE_LV_DEPRECATED


#endif
